# easydubins

## Installation

You can install the easydubins from [PyPI](https://pypi.org/project/easydubins/):

    pip install easydubins

The easydubins is supported on Python 2.7, as well as Python 3.4 and above.

## How to use

To call the easydubins in your own Python code, by importing from the `easydubins` package:

    >>> from easydubins import dubin_path
